@@ -7,6 +7,15 @@ from .drivers.postgresql import PostgreSQLAdapter
 from .versioned import Versioned
 
 
+def make_versioned(mapper):
+    sa.event.listen(
+        mapper, 'instrument_class', instrument_versioned_classes
+    )
+    sa.event.listen(
+        mapper, 'after_configured', configure_versioned_classes
+    )
+
+
 def create_transaction_log(cls):
     class TransactionLog(cls.__versioned__['base_classes'][0]):
         __tablename__ = 'transaction_log'
@@ -16,8 +25,15 @@ def create_transaction_log(cls):
     return TransactionLog
 
 
-def configure_versioned():
+def instrument_versioned_classes(mapper, cls):
+    if issubclass(cls, Versioned):
+        if not cls.__versioned__.get('class') and cls not in cls.__pending__:
+            cls.__pending__.append(cls)
+
+
+def configure_versioned_classes():
     tables = {}
+
     cls = None
     for cls in Versioned.__pending__:
         existing_table = None
